CKEDITOR.plugins.setLang("docprops","pl",{bgColor:"Kolor tła",bgFixed:"Tło nieruchome (nieprzewijające się)",bgImage:"Adres URL obrazka tła",charset:"Kodowanie znaków",charsetASCII:"ASCII",charsetCE:"Środkowoeuropejskie",charsetCR:"Cyrylica",charsetCT:"Chińskie tradycyjne (Big5)",charsetGR:"Greckie",charsetJP:"Japońskie",charsetKR:"Koreańskie",charsetOther:"Inne kodowanie znaków",charsetTR:"Tureckie",charsetUN:"Unicode (UTF-8)",charsetWE:"Zachodnioeuropejskie",chooseColor:"Wybierz",design:"Projekt strony",
docTitle:"Tytuł strony",docType:"Definicja typu dokumentu",docTypeOther:"Inna definicja typu dokumentu",label:"Właściwości dokumentu",margin:"Marginesy strony",marginBottom:"Dolny",marginLeft:"Lewy",marginRight:"Prawy",marginTop:"Górny",meta:"Znaczniki meta",metaAuthor:"Autor",metaCopyright:"Prawa autorskie",metaDescription:"Opis dokumentu",metaKeywords:"Słowa kluczowe dokumentu (oddzielone przecinkami)",other:"Inne",previewHtml:'<p>To jest <strong>przykładowy tekst</strong>. Korzystasz z programu <a href="javascript:void(0)">CKEditor</a>.</p>',
title:"Właściwości dokumentu",txtColor:"Kolor tekstu",xhtmlDec:"Uwzględnij deklaracje XHTML"});