CKEDITOR.plugins.setLang("wsc","ms",{btnIgnore:"Biar",btnIgnoreAll:"Biarkan semua",btnReplace:"Ganti",btnReplaceAll:"Gantikan Semua",btnUndo:"Batalkan",changeTo:"Tukarkan kepada",errorLoading:"Error loading application service host: %s.",ieSpellDownload:"Pemeriksa ejaan tidak dipasang. Adakah anda mahu muat turun sekarang?",manyChanges:"Pemeriksaan ejaan siap: %1 perkataan diubah",noChanges:"Pemeriksaan ejaan siap: Tiada perkataan diubah",noMispell:"Pemeriksaan ejaan siap: Tiada salah ejaan",noSuggestions:"- Tiada cadangan -",
notAvailable:"Sorry, but service is unavailable now.",notInDic:"Tidak terdapat didalam kamus",oneChange:"Pemeriksaan ejaan siap: Satu perkataan telah diubah",progress:"Pemeriksaan ejaan sedang diproses...",title:"Spell Checker",toolbar:"Semak Ejaan"});