CKEDITOR.plugins.setLang("embedbase","da",{pathName:"media objekt",title:"Media Embed",button:"Indsæt Media Embed",unsupportedUrlGiven:"Den angivende URL er ikke undersøttet.",unsupportedUrl:"URLen {url} er ikke undersøttet af Media Embed.",fetchingFailedGiven:"Kunne ikke hente indholdet fra den angivende URL.",fetchingFailed:"Kunne ikke hente indholdet fra {url}.",fetchingOne:"Henter oEmbed-svar",fetchingMany:"Henter oEmbed-svar, {current} af {max} færdige..."});