CKEDITOR.plugins.setLang("embedbase","nb",{pathName:"mediaobjekt",title:"Media-innbygging",button:"Sett inn mediaobjekt",unsupportedUrlGiven:"Den oppgitte URL-en er ikke støttet.",unsupportedUrl:"URL-en {url} er ikke støttet av Media-innbygging.",fetchingFailedGiven:"Kunne ikke hente innhold for den oppgitte URL-en.",fetchingFailed:"Kunne ikke hente innhold for {url}.",fetchingOne:"Henter oEmbed-svar...",fetchingMany:"Henter oEmbed-svar, {current} av {max} fullført..."});