CKEDITOR.plugins.setLang("docprops","km",{bgColor:"ពណ៌​ផ្ទៃ​ក្រោយ",bgFixed:"ផ្ទៃ​ក្រោយ​គ្មាន​ការ​រំកិល (នឹង​ថ្កល់)",bgImage:"URL រូបភាព​ផ្ទៃ​ក្រោយ",charset:"ការ​អ៊ិនកូដ​តួ​អក្សរ",charsetASCII:"ASCII",charsetCE:"អឺរ៉ុប​កណ្ដាល",charsetCR:"Cyrillic",charsetCT:"ចិន​បុរាណ (Big5)",charsetGR:"ក្រិក",charsetJP:"ជប៉ុន",charsetKR:"កូរ៉េ",charsetOther:"កំណត់លេខកូតភាសាផ្សេងទៀត",charsetTR:"ទួរគី",charsetUN:"យូនីកូដ (UTF-8)",charsetWE:"អឺរ៉ុប​ខាង​លិច",chooseColor:"រើស",design:"រចនា",docTitle:"ចំណងជើងទំព័រ",docType:"ប្រភេទក្បាលទំព័រ​ឯកសារ",
docTypeOther:"ប្រភេទក្បាលទំព័រឯកសារ​ផ្សេងទៀត",label:"លក្ខណៈ​សម្បត្តិ​ឯកសារ",margin:"រឹម​ទំព័រ",marginBottom:"បាត​ក្រោម",marginLeft:"ឆ្វេង",marginRight:"ស្ដាំ",marginTop:"លើ",meta:"ស្លាក​មេតា",metaAuthor:"អ្នកនិពន្ធ",metaCopyright:"រក្សាសិទ្ធិ",metaDescription:"សេចក្តីអត្ថាធិប្បាយអំពីឯកសារ",metaKeywords:"ពាក្យនៅក្នុងឯកសារ (ផ្តាច់ពីគ្នាដោយក្បៀស)",other:"ដទៃ​ទៀត...",previewHtml:'<p>នេះ​គឺ​ជា<strong>អក្សរ​គំរូ</strong>​ខ្លះៗ។ អ្នក​កំពុង​ប្រើ <a href="javascript:void(0)">CKEditor</a>។</p>',title:"ការកំណត់ ឯកសារ",
txtColor:"ពណ៌អក្សរ",xhtmlDec:"បញ្ជូល XHTML"});