CKEDITOR.plugins.setLang("mathjax","pt",{title:"Matemática em TeX",button:"Matemática",dialogInput:"Escreva aqui o seu Tex",docUrl:"http://en.wikibooks.org/wiki/LaTeX/Mathematics",docLabel:"Documentação TeX",loading:"a carregar ...",pathName:"matemática"});