CKEDITOR.plugins.setLang("mathjax","sq",{title:"Matematikë në TeX",button:"Matematikë",dialogInput:"Shkruani TeX-in tuaj këtu",docUrl:"http://en.wikibooks.org/wiki/LaTeX/Mathematics",docLabel:"Tex dokumentimi",loading:"duke u hapur...",pathName:"matematikë"});