CKEDITOR.plugins.setLang("wsc","ko",{btnIgnore:"건너뜀",btnIgnoreAll:"모두 건너뜀",btnReplace:"변경",btnReplaceAll:"모두 변경",btnUndo:"취소",changeTo:"변경할 단어",errorLoading:"Error loading application service host: %s.",ieSpellDownload:"철자 검사기가 철치되지 않았습니다. 지금 다운로드하시겠습니까?",manyChanges:"철자검사 완료: %1 단어가 변경되었습니다.",noChanges:"철자검사 완료: 변경된 단어가 없습니다.",noMispell:"철자검사 완료: 잘못된 철자가 없습니다.",noSuggestions:"- 추천단어 없음 -",notAvailable:"Sorry, but service is unavailable now.",notInDic:"사전에 없는 단어",oneChange:"철자검사 완료: 단어가 변경되었습니다.",
progress:"철자검사를 진행중입니다...",title:"Spell Check",toolbar:"철자검사"});