CKEDITOR.plugins.setLang("wsc","gu",{btnIgnore:"ઇગ્નોર/અવગણના કરવી",btnIgnoreAll:"બધાની ઇગ્નોર/અવગણના કરવી",btnReplace:"બદલવું",btnReplaceAll:"બધા બદલી કરો",btnUndo:"અન્ડૂ",changeTo:"આનાથી બદલવું",errorLoading:"સર્વિસ એપ્લીકેશન લોડ નથી થ: %s.",ieSpellDownload:"સ્પેલ-ચેકર ઇન્સ્ટોલ નથી. શું તમે ડાઉનલોડ કરવા માંગો છો?",manyChanges:"શબ્દની જોડણી/સ્પેલ ચેક પૂર્ણ: %1 શબ્દ બદલયા છે",noChanges:"શબ્દની જોડણી/સ્પેલ ચેક પૂર્ણ: એકપણ શબ્દ બદલયો નથી",noMispell:"શબ્દની જોડણી/સ્પેલ ચેક પૂર્ણ: ખોટી જોડણી મળી નથી",
noSuggestions:"- કઇ સજેશન નથી -",notAvailable:"માફ કરશો, આ સુવિધા ઉપલબ્ધ નથી",notInDic:"શબ્દકોશમાં નથી",oneChange:"શબ્દની જોડણી/સ્પેલ ચેક પૂર્ણ: એક શબ્દ બદલયો છે",progress:"શબ્દની જોડણી/સ્પેલ ચેક ચાલુ છે...",title:"સ્પેલ ",toolbar:"જોડણી (સ્પેલિંગ) તપાસવી"});