CKEDITOR.plugins.setLang("embedbase","ko",{pathName:"미디어 오브젝트",title:"미디어 임베드",button:"미디어 임베드 삽입",unsupportedUrlGiven:"지원하지 않는 주소 형식입니다.",unsupportedUrl:"입력하신 주소 {url}은 지원되지 않는 형식입니다.",fetchingFailedGiven:"입력하신 주소에서 내용을 불러올 수 없습니다.",fetchingFailed:"입력하신  주소 {url}에서 내용을 불러올 수 없습니다.",fetchingOne:"oEmbed 응답을 가져오는 중...",fetchingMany:"총 {max} 개 중{current} 번째 oEmbed 응답을 가져오는 중..."});