CKEDITOR.plugins.setLang("docprops","eu",{bgColor:"Atzeko Kolorea",bgFixed:"Korritze gabeko Atzealdea",bgImage:"Atzeko Irudiaren URL-a",charset:"Karaktere Multzoaren Kodeketa",charsetASCII:"ASCII",charsetCE:"Erdialdeko Europakoa",charsetCR:"Zirilikoa",charsetCT:"Txinatar Tradizionala (Big5)",charsetGR:"Grekoa",charsetJP:"Japoniarra",charsetKR:"Korearra",charsetOther:"Beste Karaktere Multzoko Kodeketa",charsetTR:"Turkiarra",charsetUN:"Unicode (UTF-8)",charsetWE:"Mendebaldeko Europakoa",chooseColor:"Choose",
design:"Diseinua",docTitle:"Orriaren Izenburua",docType:"Document Type Goiburua",docTypeOther:"Beste Document Type Goiburua",label:"Dokumentuaren Ezarpenak",margin:"Orrialdearen marjinak",marginBottom:"Behean",marginLeft:"Ezkerrean",marginRight:"Eskuman",marginTop:"Goian",meta:"Meta Informazioa",metaAuthor:"Egilea",metaCopyright:"Copyright",metaDescription:"Dokumentuaren Deskribapena",metaKeywords:"Dokumentuaren Gako-hitzak (komarekin bananduta)",other:"<other>",previewHtml:'<p>Hau <strong>adibideko testua</strong> da. <a href="javascript:void(0)">CKEditor</a> erabiltzen ari zara.</p>',
title:"Dokumentuaren Ezarpenak",txtColor:"Testu Kolorea",xhtmlDec:"XHTML Ezarpenak"});