CKEDITOR.plugins.setLang("mathjax","zh",{title:"以 TeX 表示數學",button:"數學",dialogInput:"請輸入 TeX",docUrl:"http://en.wikibooks.org/wiki/LaTeX/Mathematics",docLabel:"TeX 說明文件",loading:"載入中…",pathName:"數學"});