CKEDITOR.plugins.setLang("image2","fr",{alt:"Texte de remplacement",btnUpload:"Envoyer sur le serveur",captioned:"Image légendée",captionPlaceholder:"Légende",infoTab:"Informations sur l'image2",lockRatio:"Conserver les proportions",menu:"Propriétés de l'image2",pathName:"image",pathNameCaption:"légende",resetSize:"Taille d'origine",resizer:"Cliquer et glisser pour redimensionner",title:"Propriétés de l'image2",uploadTab:"Envoyer",urlMissing:"L'adresse source de l'image est manquante."});