/*
 Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("uicolor","eo",{title:"UI Kolorselektilo",preview:"Vidigi la aspekton",config:"Gluu tiun signoĉenon en vian dosieron config.js",predefined:"Antaŭdifinita koloraro"});