CKEDITOR.plugins.setLang("mathjax","ar",{title:"الرياصيات في Tex",button:"رياضيات",dialogInput:"أكتب Tex خاصتك هنا",docUrl:"http://en.wikibooks.org/wiki/LaTeX/Mathematics",docLabel:"وثائق Tex",loading:"جاري التحميل...",pathName:"رياضيات"});