CKEDITOR.plugins.setLang("docprops","sq",{bgColor:"Ngjyra e Prapavijës",bgFixed:"Prapavijë pa zvarritje (fiks)",bgImage:"URL e Fotografisë së Prapavijës",charset:"Character Set Encoding",charsetASCII:"ASCII",charsetCE:"Evropës Qendrore",charsetCR:"Sllave",charsetCT:"Kinezisht Tradicional (Big5)",charsetGR:"Greke",charsetJP:"Japoneze",charsetKR:"Koreane",charsetOther:"Other Character Set Encoding",charsetTR:"Turke",charsetUN:"Unicode (UTF-8)",charsetWE:"Evropiano Perëndimor",chooseColor:"Përzgjidh",
design:"Dizajni",docTitle:"Titulli i Faqes",docType:"Document Type Heading",docTypeOther:"Koka e Llojit Tjetër të Dokumentit",label:"Karakteristikat e Dokumentit",margin:"Kufijtë e Faqes",marginBottom:"Poshtë",marginLeft:"Majtas",marginRight:"Djathtas",marginTop:"Lart",meta:"Meta Tags",metaAuthor:"Autori",metaCopyright:"Të drejtat e kopjimit",metaDescription:"Përshkrimi i Dokumentit",metaKeywords:"Fjalët kyçe të indeksimit të dokumentit (të ndarë me presje)",other:"Tjera...",previewHtml:'<p>Ky është nje <strong>tekst shembull</strong>.  Ju jeni duke shfrytëzuar <a href="javascript:void(0)">CKEditor</a>.</p>',
title:"Karakteristikat e Dokumentit",txtColor:"Ngjyra e Tekstit",xhtmlDec:"Përfshij XHTML Deklarimet"});