CKEDITOR.plugins.setLang("docprops","fi",{bgColor:"Taustaväri",bgFixed:"Paikallaanpysyvä tausta",bgImage:"Taustakuva",charset:"Merkistökoodaus",charsetASCII:"ASCII",charsetCE:"Keskieurooppalainen",charsetCR:"Kyrillinen",charsetCT:"Kiina, perinteinen (Big5)",charsetGR:"Kreikka",charsetJP:"Japani",charsetKR:"Korealainen",charsetOther:"Muu merkistökoodaus",charsetTR:"Turkkilainen",charsetUN:"Unicode (UTF-8)",charsetWE:"Länsieurooppalainen",chooseColor:"Valitse",design:"Sommittelu",docTitle:"Sivun nimi",
docType:"Dokumentin tyyppi",docTypeOther:"Muu dokumentin tyyppi",label:"Dokumentin ominaisuudet",margin:"Sivun marginaalit",marginBottom:"Ala",marginLeft:"Vasen",marginRight:"Oikea",marginTop:"Ylä",meta:"Metatieto",metaAuthor:"Tekijä",metaCopyright:"Tekijänoikeudet",metaDescription:"Kuvaus",metaKeywords:"Hakusanat (pilkulla erotettuna)",other:"<muu>",previewHtml:'<p>Tämä on <strong>esimerkkitekstiä</strong>. Käytät juuri <a href="javascript:void(0)">CKEditoria</a>.</p>',title:"Dokumentin ominaisuudet",
txtColor:"Tekstiväri",xhtmlDec:"Lisää XHTML julistukset"});